@@ -22,7 +22,6 @@
 #include <math.h>
 
 #include "meta-draw-op-private.h"
-#include "meta-theme-impl-private.h"
 
 #define GDK_COLOR_RGB(color)                             \
         ((guint32) (((int)((color).red * 255) << 16)   | \
@@ -73,6 +72,8 @@ fill_env (MetaPositionExprEnv *env,
 
   env->title_width = info->title_layout_width;
   env->title_height = info->title_layout_height;
+
+  env->scale = info->scale;
 }
 
 static cairo_surface_t *
@@ -274,24 +275,6 @@ draw_op_as_surface (const MetaDrawOp   *op,
 
   switch (op->type)
     {
-    case META_DRAW_LINE:
-      break;
-
-    case META_DRAW_RECTANGLE:
-      break;
-
-    case META_DRAW_ARC:
-      break;
-
-    case META_DRAW_CLIP:
-      break;
-
-    case META_DRAW_TINT:
-      break;
-
-    case META_DRAW_GRADIENT:
-      break;
-
     case META_DRAW_IMAGE:
       {
         if (op->data.image.colorize_spec)
@@ -335,11 +318,6 @@ draw_op_as_surface (const MetaDrawOp   *op,
         break;
       }
 
-    case META_DRAW_GTK_ARROW:
-    case META_DRAW_GTK_BOX:
-    case META_DRAW_GTK_VLINE:
-      break;
-
     case META_DRAW_ICON:
       if (info->mini_icon &&
           width <= gdk_pixbuf_get_width (info->mini_icon) &&
@@ -351,12 +329,17 @@ draw_op_as_surface (const MetaDrawOp   *op,
                                            width, height, FALSE, FALSE);
       break;
 
+    case META_DRAW_TINT:
+    case META_DRAW_LINE:
+    case META_DRAW_RECTANGLE:
+    case META_DRAW_ARC:
+    case META_DRAW_CLIP:
+    case META_DRAW_GRADIENT:
+    case META_DRAW_GTK_ARROW:
+    case META_DRAW_GTK_BOX:
+    case META_DRAW_GTK_VLINE:
     case META_DRAW_TITLE:
-      break;
-
     case META_DRAW_OP_LIST:
-      break;
-
     case META_DRAW_TILE:
       break;
 
@@ -576,7 +559,7 @@ draw_op_draw_with_env (const MetaDrawOp    *op,
         gdouble rx, ry, rwidth, rheight;
         cairo_surface_t *surface;
 
-        scale = get_window_scaling_factor ();
+        scale = info->scale;
         cairo_scale (cr, 1.0 / scale, 1.0 / scale);
 
         if (op->data.image.pixbuf)
@@ -1162,17 +1145,6 @@ meta_draw_op_list_draw_with_style (const MetaDrawOpList *op_list,
 
   fill_env (&env, info, rect);
 
-  /* FIXME this can be optimized, potentially a lot, by
-   * compressing multiple ops when possible. For example,
-   * anything convertible to a pixbuf can be composited
-   * client-side, and putting a color tint over a pixbuf
-   * can be done without creating the solid-color pixbuf.
-   *
-   * To implement this my plan is to have the idea of a
-   * compiled draw op (with the string expressions already
-   * evaluated), we make an array of those, and then fold
-   * adjacent items when possible.
-   */
   cairo_save (cr);
 
   for (i = 0; i < op_list->n_ops; i++)
