@@ -21,13 +21,27 @@
 
 #include <gtk/gtk.h>
 
-#include "meta-gradient-private.h"
-
 G_BEGIN_DECLS
 
 typedef struct _MetaAlphaGradientSpec MetaAlphaGradientSpec;
 typedef struct _MetaGradientSpec MetaGradientSpec;
 
+/**
+ * MetaGradientType:
+ * @META_GRADIENT_VERTICAL: Vertical gradient
+ * @META_GRADIENT_HORIZONTAL: Horizontal gradient
+ * @META_GRADIENT_DIAGONAL: Diagonal gradient
+ * @META_GRADIENT_LAST: Marks the end of the #MetaGradientType enumeration
+ *
+ */
+typedef enum
+{
+  META_GRADIENT_VERTICAL,
+  META_GRADIENT_HORIZONTAL,
+  META_GRADIENT_DIAGONAL,
+  META_GRADIENT_LAST
+} MetaGradientType;
+
 G_GNUC_INTERNAL
 MetaGradientSpec      *meta_gradient_spec_new               (MetaGradientType         type);
 
