@@ -22,6 +22,7 @@
 
 #include "display-private.h"
 #include "meta-compositor-vulkan.h"
+#include "meta-enum-types.h"
 #include "meta-surface-vulkan.h"
 #include "prefs.h"
 #include "screen.h"
@@ -810,7 +811,9 @@ device_type_to_string (VkPhysicalDeviceType type)
         return "cpu";
         break;
 
+#if VK_HEADER_VERSION < 140
       case VK_PHYSICAL_DEVICE_TYPE_RANGE_SIZE:
+#endif
       case VK_PHYSICAL_DEVICE_TYPE_MAX_ENUM:
       default:
         break;
@@ -1184,16 +1187,25 @@ meta_compositor_vulkan_finalize (GObject *object)
 static gboolean
 not_implemented_cb (MetaCompositorVulkan *vulkan)
 {
-  gboolean cm;
+  MetaDisplay *display;
+  MetaCompositorType type;
+  GEnumClass *enum_class;
+  GEnumValue *enum_value;
 
-  cm = meta_prefs_get_compositing_manager ();
+  display = meta_compositor_get_display (META_COMPOSITOR (vulkan));
+  type = meta_prefs_get_compositor ();
 
-  g_warning ("MetaCompositorVulkan is not implemented, switching to %s...",
-             cm ? "MetaCompositorXRender" : "MetaCompositorNone");
+  enum_class = g_type_class_ref (META_TYPE_COMPOSITOR_TYPE);
+  enum_value = g_enum_get_value (enum_class, type);
+  g_assert_nonnull (enum_value);
+
+  g_warning ("“vulkan” compositor is not implemented, switching to “%s”...",
+             enum_value->value_nick);
+
+  g_type_class_unref (enum_class);
 
   g_unsetenv ("META_COMPOSITOR");
-  meta_prefs_set_compositing_manager (!cm);
-  meta_prefs_set_compositing_manager (cm);
+  meta_display_update_compositor (display);
 
   return G_SOURCE_REMOVE;
 }
