@@ -2,9 +2,9 @@
 
 /* Metacity window placement */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -14,7 +14,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,7 +26,7 @@
 #include "frame-private.h"
 
 void meta_window_place (MetaWindow *window,
-                        MetaFrameGeometry *fgeom,
+                        MetaFrameBorders *borders,
                         int         x,
                         int         y,
                         int        *new_x,
