@@ -229,7 +229,7 @@ meta_stack_tracker_dump (MetaStackTracker *tracker)
 static void
 meta_stack_op_free (MetaStackOp *op)
 {
-  g_slice_free (MetaStackOp, op);
+  g_free (op);
 }
 
 static int
@@ -510,7 +510,7 @@ meta_stack_tracker_record_add (MetaStackTracker *tracker,
                                Window            window,
                                gulong            serial)
 {
-  MetaStackOp *op = g_slice_new (MetaStackOp);
+  MetaStackOp *op = g_new0 (MetaStackOp, 1);
 
   op->any.type = STACK_OP_ADD;
   op->any.serial = serial;
@@ -524,7 +524,7 @@ meta_stack_tracker_record_remove (MetaStackTracker *tracker,
                                   Window            window,
                                   gulong            serial)
 {
-  MetaStackOp *op = g_slice_new (MetaStackOp);
+  MetaStackOp *op = g_new0 (MetaStackOp, 1);
 
   op->any.type = STACK_OP_REMOVE;
   op->any.serial = serial;
@@ -539,7 +539,7 @@ meta_stack_tracker_record_raise_above (MetaStackTracker *tracker,
                                        Window            sibling,
                                        gulong            serial)
 {
-  MetaStackOp *op = g_slice_new (MetaStackOp);
+  MetaStackOp *op = g_new0 (MetaStackOp, 1);
 
   op->any.type = STACK_OP_RAISE_ABOVE;
   op->any.serial = serial;
@@ -555,7 +555,7 @@ meta_stack_tracker_record_lower_below (MetaStackTracker *tracker,
                                        Window            sibling,
                                        gulong            serial)
 {
-  MetaStackOp *op = g_slice_new (MetaStackOp);
+  MetaStackOp *op = g_new0 (MetaStackOp, 1);
 
   op->any.type = STACK_OP_LOWER_BELOW;
   op->any.serial = serial;
