@@ -28,19 +28,15 @@
 
 #define NUM_RANDOM_RUNS 10000
 
-static void
-init_random_ness (void)
-{
-  srand(time(NULL));
-}
+static GRand *grand = NULL;
 
 static void
 get_random_rect (MetaRectangle *rect)
 {
-  rect->x = rand () % 1600;
-  rect->y = rand () % 1200;
-  rect->width  = rand () % 1600 + 1;
-  rect->height = rand () % 1200 + 1;
+  rect->x = g_rand_int (grand) % 1600;
+  rect->y = g_rand_int (grand) % 1200;
+  rect->width  = g_rand_int (grand) % 1600 + 1;
+  rect->height = g_rand_int (grand) % 1200 + 1;
 }
 
 static MetaRectangle*
@@ -1365,7 +1361,9 @@ test_find_closest_point_to_line (void)
                                                   x2,  y2,
                                                   px,  py,
                                                   &rx, &ry);
-  g_assert (rx == answer_x && ry == answer_y);
+
+  g_assert_cmpfloat_with_epsilon (rx, answer_x, 0.0001);
+  g_assert_cmpfloat_with_epsilon (ry, answer_y, 0.0001);
 
   /* Special test for x1 == x2, so that slop of line is infinite */
   x1 =  3.0;  y1 =  49.0;
@@ -1376,7 +1374,9 @@ test_find_closest_point_to_line (void)
                                                   x2,  y2,
                                                   px,  py,
                                                   &rx, &ry);
-  g_assert (rx == answer_x && ry == answer_y);
+
+  g_assert_cmpfloat_with_epsilon (rx, answer_x, 0.0001);
+  g_assert_cmpfloat_with_epsilon (ry, answer_y, 0.0001);
 
   /* Special test for y1 == y2, so perp line has slope of infinity */
   x1 =  3.14;  y1 =   7.0;
@@ -1387,7 +1387,9 @@ test_find_closest_point_to_line (void)
                                                   x2,  y2,
                                                   px,  py,
                                                   &rx, &ry);
-  g_assert (rx == answer_x && ry == answer_y);
+
+  g_assert_cmpfloat_with_epsilon (rx, answer_x, 0.0001);
+  g_assert_cmpfloat_with_epsilon (ry, answer_y, 0.0001);
 
   /* Test when we the point we want to be closest to is actually on the line */
   x1 =  3.0;  y1 =  49.0;
@@ -1398,7 +1400,9 @@ test_find_closest_point_to_line (void)
                                                   x2,  y2,
                                                   px,  py,
                                                   &rx, &ry);
-  g_assert (rx == answer_x && ry == answer_y);
+
+  g_assert_cmpfloat_with_epsilon (rx, answer_x, 0.0001);
+  g_assert_cmpfloat_with_epsilon (ry, answer_y, 0.0001);
 
   printf ("%s passed.\n", G_STRFUNC);
 }
@@ -1406,7 +1410,8 @@ test_find_closest_point_to_line (void)
 int
 main (int argc, char **argv)
 {
-  init_random_ness ();
+  grand = g_rand_new ();
+
   test_area ();
   test_intersect ();
   test_equal ();
@@ -1428,6 +1433,8 @@ main (int argc, char **argv)
   test_gravity_resize ();
   test_find_closest_point_to_line ();
 
+  g_rand_free (grand);
+
   printf ("All tests passed.\n");
   return 0;
 }
