@@ -234,25 +234,6 @@ atom_list_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
-gboolean
-meta_prop_get_atom_list (MetaDisplay *display,
-                         Window       xwindow,
-                         Atom         xatom,
-                         Atom       **atoms_p,
-                         int         *n_atoms_p)
-{
-  GetPropertyResults results;
-
-  *atoms_p = NULL;
-  *n_atoms_p = 0;
-
-  if (!get_property (display, xwindow, xatom, XA_ATOM,
-                     &results))
-    return FALSE;
-
-  return atom_list_from_results (&results, atoms_p, n_atoms_p);
-}
-
 static gboolean
 cardinal_list_from_results (GetPropertyResults *results,
                             gulong            **cardinals_p,
@@ -424,24 +405,6 @@ utf8_string_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
-gboolean
-meta_prop_get_utf8_string (MetaDisplay *display,
-                           Window       xwindow,
-                           Atom         xatom,
-                           char       **str_p)
-{
-  GetPropertyResults results;
-
-  *str_p = NULL;
-
-  if (!get_property (display, xwindow, xatom,
-                     display->atom_UTF8_STRING,
-                     &results))
-    return FALSE;
-
-  return utf8_string_from_results (&results, str_p);
-}
-
 /* this one freakishly returns g_malloc memory */
 static gboolean
 utf8_list_from_results (GetPropertyResults *results,
@@ -713,21 +676,6 @@ text_property_from_results (GetPropertyResults *results,
   return *utf8_str_p != NULL;
 }
 
-gboolean
-meta_prop_get_text_property (MetaDisplay   *display,
-                             Window         xwindow,
-                             Atom           xatom,
-                             char         **utf8_str_p)
-{
-  GetPropertyResults results;
-
-  if (!get_property (display, xwindow, xatom, AnyPropertyType,
-                     &results))
-    return FALSE;
-
-  return text_property_from_results (&results, utf8_str_p);
-}
-
 /* From Xmd.h */
 #ifndef cvtINT32toInt
 #if SIZEOF_VOID_P == 8
@@ -803,23 +751,6 @@ wm_hints_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
-gboolean
-meta_prop_get_wm_hints (MetaDisplay   *display,
-                        Window         xwindow,
-                        Atom           xatom,
-                        XWMHints     **hints_p)
-{
-  GetPropertyResults results;
-
-  *hints_p = NULL;
-
-  if (!get_property (display, xwindow, xatom, XA_WM_HINTS,
-                     &results))
-    return FALSE;
-
-  return wm_hints_from_results (&results, hints_p);
-}
-
 static gboolean
 class_hint_from_results (GetPropertyResults *results,
                          XClassHint         *class_hint)
@@ -864,34 +795,15 @@ class_hint_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
-gboolean
-meta_prop_get_class_hint (MetaDisplay   *display,
-                          Window         xwindow,
-                          Atom           xatom,
-                          XClassHint    *class_hint)
-{
-  GetPropertyResults results;
-
-  class_hint->res_class = NULL;
-  class_hint->res_name = NULL;
-
-  if (!get_property (display, xwindow, xatom, XA_STRING,
-                     &results))
-    return FALSE;
-
-  return class_hint_from_results (&results, class_hint);
-}
-
 static gboolean
-size_hints_from_results (GetPropertyResults *results,
-                         XSizeHints        **hints_p,
-                         gulong             *flags_p)
+size_hints_from_results (GetPropertyResults  *results,
+                         XSizeHints         **hints_p)
 {
   xPropSizeHints *raw;
   XSizeHints *hints;
+  gulong flags;
 
   *hints_p = NULL;
-  *flags_p = 0;
 
   if (!validate_or_free_results (results, 32, XA_WM_SIZE_HINTS, FALSE))
     return FALSE;
@@ -920,16 +832,16 @@ size_hints_from_results (GetPropertyResults *results,
   hints->max_aspect.x = cvtINT32toInt (raw->maxAspectX);
   hints->max_aspect.y = cvtINT32toInt (raw->maxAspectY);
 
-  *flags_p = (USPosition | USSize | PAllHints);
+  flags = (USPosition | USSize | PAllHints);
   if (results->n_items >= NumPropSizeElements)
     {
       hints->base_width= cvtINT32toInt (raw->baseWidth);
       hints->base_height= cvtINT32toInt (raw->baseHeight);
       hints->win_gravity= cvtINT32toInt (raw->winGravity);
-      *flags_p |= (PBaseSize | PWinGravity);
+      flags |= (PBaseSize | PWinGravity);
     }
 
-  hints->flags &= (*flags_p);	/* get rid of unwanted bits */
+  hints->flags &= flags; /* get rid of unwanted bits */
 
   XFree (results->prop);
   results->prop = NULL;
@@ -939,25 +851,6 @@ size_hints_from_results (GetPropertyResults *results,
   return TRUE;
 }
 
-gboolean
-meta_prop_get_size_hints (MetaDisplay   *display,
-                          Window         xwindow,
-                          Atom           xatom,
-                          XSizeHints   **hints_p,
-                          gulong        *flags_p)
-{
-  GetPropertyResults results;
-
-  *hints_p = NULL;
-  *flags_p = 0;
-
-  if (!get_property (display, xwindow, xatom, XA_WM_SIZE_HINTS,
-                     &results))
-    return FALSE;
-
-  return size_hints_from_results (&results, hints_p, flags_p);
-}
-
 static AgGetPropertyTask*
 get_task (MetaDisplay        *display,
           Window              xwindow,
@@ -1204,9 +1097,7 @@ meta_prop_get_values (MetaDisplay   *display,
             values[i].type = META_PROP_VALUE_INVALID;
           break;
         case META_PROP_VALUE_SIZE_HINTS:
-          if (!size_hints_from_results (&results,
-                                        &values[i].v.size_hints.hints,
-                                        &values[i].v.size_hints.flags))
+          if (!size_hints_from_results (&results, &values[i].v.size_hints))
             values[i].type = META_PROP_VALUE_INVALID;
           break;
         case META_PROP_VALUE_SYNC_COUNTER:
@@ -1264,7 +1155,7 @@ free_value (MetaPropValue *value)
       meta_XFree (value->v.class_hint.res_name);
       break;
     case META_PROP_VALUE_SIZE_HINTS:
-      meta_XFree (value->v.size_hints.hints);
+      meta_XFree (value->v.size_hints);
       break;
     case META_PROP_VALUE_UTF8_LIST:
       g_strfreev (value->v.string_list.strings);
