@@ -26,9 +26,6 @@
 #include "common.h"
 #include "types.h"
 
-void    meta_frame_get_mask     (MetaFrame        *frame,
-                                 cairo_t          *cr);
-
 Visual *meta_frame_get_xvisual  (MetaFrame        *frame);
 
 Window  meta_frame_get_xwindow  (MetaFrame        *frame);
